Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(506)

Unified Diff: components/password_manager/core/common/credential_manager_types.h

Issue 1209363003: Rename avatar to icon in the credential manager in Chromium. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Added TODO. Created 5 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/password_manager/core/common/credential_manager_types.h
diff --git a/components/password_manager/core/common/credential_manager_types.h b/components/password_manager/core/common/credential_manager_types.h
index 76ae09d96829bb6d0008aa0acda654947a7cc05f..19e2124c6850b661b2c37a6414534264f2499c50 100644
--- a/components/password_manager/core/common/credential_manager_types.h
+++ b/components/password_manager/core/common/credential_manager_types.h
@@ -44,9 +44,9 @@ struct CredentialInfo {
// property.
base::string16 name;
- // The address of a user's avatar. Corresponds to WebCredential's avatar
- // property.
- GURL avatar;
+ // The address of this credential's icon (e.g. the user's avatar).
+ // Corresponds to WebCredential's icon property.
+ GURL icon;
// Corresponds to WebPasswordCredential's password property.
base::string16 password;

Powered by Google App Engine
This is Rietveld 408576698